summaryrefslogtreecommitdiffstats
path: root/konsolekalendar/konsolekalendaradd.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'konsolekalendar/konsolekalendaradd.cpp')
-rw-r--r--konsolekalendar/konsolekalendaradd.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/konsolekalendar/konsolekalendaradd.cpp b/konsolekalendar/konsolekalendaradd.cpp
index e1c80498..bd198073 100644
--- a/konsolekalendar/konsolekalendaradd.cpp
+++ b/konsolekalendar/konsolekalendaradd.cpp
@@ -20,8 +20,8 @@
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA. *
* *
* As a special exception, permission is given to link this program *
* with any edition of Qt, and distribute the resulting executable, *
* without including the source code for Qt in the source distribution. *
* *
******************************************************************************/
/**
@@ -146,11 +146,11 @@ void KonsoleKalendarAdd::printSpecs()
<< endl;
cout << i18n( " Begin: %1" ).
- arg( m_variables->getStartDateTime().toString( Qt::TextDate ) ).local8Bit()
+ arg( m_variables->getStartDateTime().toString( TQt::TextDate ) ).local8Bit()
<< endl;
cout << i18n( " End: %1" ).
- arg( m_variables->getEndDateTime().toString( Qt::TextDate ) ).local8Bit()
+ arg( m_variables->getEndDateTime().toString( TQt::TextDate ) ).local8Bit()
<< endl;
if ( m_variables->getFloating() == true ) {
@@ -20,8 +20,8 @@
* *
* As a special exception, permission is given to link this program *
- * with any edition of Qt, and distribute the resulting executable, *
- * without including the source code for Qt in the source distribution. *
+ * with any edition of TQt, and distribute the resulting executable, *
+ * without including the source code for TQt in the source distribution. *
* *
******************************************************************************/